@@ -799,3 +799,30 @@ show_help_dialog (GtkWindow  *parent,
 	}
 	g_free (uri);
 }
+
+
+GtkBuilder * 
+_gtk_builder_new_from_file (const char *ui_file)
+{
+	char       *filename;
+	GtkBuilder *builder;
+	GError     *error = NULL;
+
+	filename = g_build_filename (UI_DIR, ui_file, NULL);
+	builder = gtk_builder_new ();
+        if (! gtk_builder_add_from_file (builder, filename, &error)) {
+                g_warning ("%s\n", error->message);
+                g_clear_error (&error);
+        }
+	g_free (filename);
+	        
+        return builder;
+}
+
+
+GtkWidget * 
+_gtk_builder_get_widget (GtkBuilder *builder,
+			 const char *name)
+{
+	return (GtkWidget *) gtk_builder_get_object (builder, name);
+}
